From 516c3eaa8f0e34cfbd93254eef3187162cf3979c Mon Sep 17 00:00:00 2001
From: Roman Telezhynskyi <kroluku@gmail.com>
Date: Fri, 11 Sep 2015 13:04:01 +0300
Subject: [PATCH] Resolved issue #355. Change Measurements 'Create new' to
 'Create/Edit'.

--HG--
branch : develop
---
 src/app/tape/tmainwindow.cpp    | 10 +++++-----
 src/app/tape/tmainwindow.ui     |  9 ++++++++-
 src/app/valentina/mainwindow.ui | 18 +++++++++---------
 3 files changed, 22 insertions(+), 15 deletions(-)

diff --git a/src/app/tape/tmainwindow.ui b/src/app/tape/tmainwindow.ui
index 3d8f43e99..c2535142c 100644
--- a/src/app/tape/tmainwindow.ui
+++ b/src/app/tape/tmainwindow.ui
@@ -645,6 +645,7 @@
     <bool>false</bool>
    </attribute>
    <addaction name="actionNew"/>
+   <addaction name="actionOpenIndividual"/>
    <addaction name="actionSave"/>
    <addaction name="actionAddKnown"/>
    <addaction name="actionAddCustom"/>
@@ -673,7 +674,7 @@
   </widget>
   <action name="actionOpenIndividual">
    <property name="icon">
-    <iconset>
+    <iconset theme="document-open">
      <normaloff/>
     </iconset>
    </property>
@@ -782,11 +783,17 @@
    </property>
   </action>
   <action name="actionOpenStandard">
+   <property name="icon">
+    <iconset theme="document-open"/>
+   </property>
    <property name="text">
     <string>Open standard ...</string>
    </property>
   </action>
   <action name="actionOpenTemplate">
+   <property name="icon">
+    <iconset theme="document-open"/>
+   </property>
    <property name="text">
     <string>Open template</string>
    </property>
diff --git a/src/app/valentina/mainwindow.ui b/src/app/valentina/mainwindow.ui
index 26788adb6..fe1bdea8e 100644
--- a/src/app/valentina/mainwindow.ui
+++ b/src/app/valentina/mainwindow.ui
@@ -372,7 +372,7 @@
         <rect>
          <x>0</x>
          <y>0</y>
-         <width>130</width>
+         <width>100</width>
          <height>58</height>
         </rect>
        </property>
@@ -458,7 +458,7 @@
         <rect>
          <x>0</x>
          <y>0</y>
-         <width>130</width>
+         <width>100</width>
          <height>156</height>
         </rect>
        </property>
@@ -622,7 +622,7 @@
         <rect>
          <x>0</x>
          <y>0</y>
-         <width>130</width>
+         <width>100</width>
          <height>196</height>
         </rect>
        </property>
@@ -864,7 +864,7 @@
         <rect>
          <x>0</x>
          <y>0</y>
-         <width>130</width>
+         <width>100</width>
          <height>58</height>
         </rect>
        </property>
@@ -950,8 +950,8 @@
         <rect>
          <x>0</x>
          <y>0</y>
-         <width>130</width>
-         <height>386</height>
+         <width>98</width>
+         <height>58</height>
         </rect>
        </property>
        <attribute name="icon">
@@ -1878,10 +1878,10 @@
   </action>
   <action name="actionCreateNew">
    <property name="text">
-    <string>Create new ...</string>
+    <string>Create/Edit</string>
    </property>
    <property name="toolTip">
-    <string>Create new measurements</string>
+    <string>Create/edit measurements</string>
    </property>
   </action>
   <action name="actionShowM">
@@ -1920,8 +1920,8 @@
   <tabstop>toolButtonSplinePath</tabstop>
  </tabstops>
  <resources>
-  <include location="../../libs/vmisc/share/resources/icon.qrc"/>
   <include location="share/resources/toolicon.qrc"/>
+  <include location="../../libs/vmisc/share/resources/icon.qrc"/>
  </resources>
  <connections/>
 </ui>
diff --git a/src/app/tape/tmainwindow.cpp b/src/app/tape/tmainwindow.cpp
index 50dcf6e35..e8a8331e3 100644
--- a/src/app/tape/tmainwindow.cpp
+++ b/src/app/tape/tmainwindow.cpp
@@ -315,7 +315,7 @@ void TMainWindow::OpenIndividual()
 {
     if (m == nullptr)
     {
-        const QString filter = tr("Individual measurements (*.vit);;Standard measurements (*.vst)");
+        const QString filter = tr("Individual measurements (*.vit);;Standard measurements (*.vst);;All files (*.*)");
         //Use standard path to individual measurements
         const QString pathTo = qApp->TapeSettings()->GetPathIndividualMeasurements();
         Open(pathTo, filter);
@@ -332,8 +332,8 @@ void TMainWindow::OpenStandard()
 {
     if (m == nullptr)
     {
-        const QString filter = tr("Standard measurements (*.vst);;Individual measurements (*.vit)");
-        //Use standard path to individual measurements
+        const QString filter = tr("Standard measurements (*.vst);;Individual measurements (*.vit);;All files (*.*)");
+        //Use standard path to standard measurements
         const QString pathTo = qApp->TapeSettings()->GetPathStandardMeasurements();
         Open(pathTo, filter);
     }
@@ -349,8 +349,8 @@ void TMainWindow::OpenTemplate()
 {
     if (m == nullptr)
     {
-        const QString filter = tr("Measurements (*.vst, *.vit)");
-        //Use standard path to individual measurements
+        const QString filter = tr("Measurements (*.vst *.vit);;All files (*.*)");
+        //Use standard path to template files
         const QString pathTo = qApp->TapeSettings()->GetPathTemplate();
         Open(pathTo, filter);
     }